==> zzyj-outputvalcount-impl-3.0.0-20240129.013951-278-sources.jar: com/ejianc/business/worklog/bean/WorkPlanEntity.java <==
package com.ejianc.business.worklog.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工作日志-工作计划
 *
 * @author generator
 */
@TableName("t_outputvalcount_work_plan")
public class WorkPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; // 单据编码
    @TableField(value = "org_id")
    private Long orgId; // 组织id
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "create_user_name")
    private String createUserName; // 编制人
    @TableField(value = "operator_id")
    private String operatorId; // 经办人ID
    @TableField(value = "operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value = "update_user_name")
    private String updateUserName; // 修改者
    @TableField(value = "remark")
    private String remark; // 备注
    @TableField(value = "work_type_id")
    private Long workTypeId; // 工作类别id
    @TableField(value = "work_type_code")
    private String workTypeCode; // 工作类别编号
    @TableField(value = "work_type_name")
    private String workTypeName; // 工作类别名称
    @TableField(value = "work_type_detail_id")
    private Long workTypeDetailId; // 工作详细类别id
    @TableField(value = "work_type_detail_code")
    private String workTypeDetailCode; // 工作详细类别编号
    @TableField(value = "work_type_detail_name")
    private String workTypeDetailName; // 工作详细类别名称
    @TableField(value = "project_code")
    private String projectCode; // 课题编号
    @TableField(value = "project_name")
    private String projectName; // 课题名称
    @TableField(value = "regist_time")
    private Date registTime; // 立项时间
    @TableField(value = "charge_org_id")
    private Long chargeOrgId; // 责任部门id
    @TableField(value = "charge_org_name")
    private String chargeOrgName; // 责任部门名称
    @TableField(value = "coordinate_org_id")
    private String coordinateOrgId; // 配合部门id
    @TableField(value = "coordinate_org_name")
    private String coordinateOrgName; // 配合部门名称
    @TableField(value = "regist_remark")
    private String registRemark; // 立项事由概述
    @TableField(value = "anticipated_results")
    private String anticipatedResults; // 预期成果
    @TableField(value = "end_time")
    private Date endTime; // 预计完成时间
    @TableField(value = "progress_id")
    private Long progressId; // 进展ID
    @TableField(value = "progress_name")
    private String progressName; // 进展
    @TableField(value = "progress_remark")
    private String progressRemark; // 进展描述
    @TableField(value = "progress_time")
    private Date progressTime; // 最新进展日期
    @TableField(value = "parent_id")
    private Long parentId; // 上级ID
    @TableField(value = "parent_name")
    private String parentName; // 上级名称
    @TableField(value = "project_source")
    private String projectSource; // 课题来源
    @TableField(value = "plan_type")
    private String planType; // 计划类型
    @TableField(value = "inner_code")
    private String innerCode; // 内码
    @TableField(value = "inner_name")
    private String innerName; // 内码名称
    @TableField(value = "finish_flag")
    private String finishFlag;//完成标识


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getWorkTypeId() {
        return workTypeId;
    }

    public void setWorkTypeId(Long workTypeId) {
        this.workTypeId = workTypeId;
    }

    public String getWorkTypeCode() {
        return workTypeCode;
    }

    public void setWorkTypeCode(String workTypeCode) {
        this.workTypeCode = workTypeCode;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }

    public Long getWorkTypeDetailId() {
        return workTypeDetailId;
    }

    public void setWorkTypeDetailId(Long workTypeDetailId) {
        this.workTypeDetailId = workTypeDetailId;
    }

    public String getWorkTypeDetailCode() {
        return workTypeDetailCode;
    }

    public void setWorkTypeDetailCode(String workTypeDetailCode) {
        this.workTypeDetailCode = workTypeDetailCode;
    }

    public String getWorkTypeDetailName() {
        return workTypeDetailName;
    }

    public void setWorkTypeDetailName(String workTypeDetailName) {
        this.workTypeDetailName = workTypeDetailName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getRegistTime() {
        return registTime;
    }

    public void setRegistTime(Date registTime) {
        this.registTime = registTime;
    }

    public Long getChargeOrgId() {
        return chargeOrgId;
    }

    public void setChargeOrgId(Long chargeOrgId) {
        this.chargeOrgId = chargeOrgId;
    }

    public String getChargeOrgName() {
        return chargeOrgName;
    }

    public void setChargeOrgName(String chargeOrgName) {
        this.chargeOrgName = chargeOrgName;
    }

    public String getCoordinateOrgId() {
        return coordinateOrgId;
    }

    public void setCoordinateOrgId(String coordinateOrgId) {
        this.coordinateOrgId = coordinateOrgId;
    }

    public String getCoordinateOrgName() {
        return coordinateOrgName;
    }

    public void setCoordinateOrgName(String coordinateOrgName) {
        this.coordinateOrgName = coordinateOrgName;
    }

    public String getRegistRemark() {
        return registRemark;
    }

    public void setRegistRemark(String registRemark) {
        this.registRemark = registRemark;
    }

    public String getAnticipatedResults() {
        return anticipatedResults;
    }

    public void setAnticipatedResults(String anticipatedResults) {
        this.anticipatedResults = anticipatedResults;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Long getProgressId() {
        return progressId;
    }

    public void setProgressId(Long progressId) {
        this.progressId = progressId;
    }

    public String getProgressName() {
        return progressName;
    }

    public void setProgressName(String progressName) {
        this.progressName = progressName;
    }

    public String getProgressRemark() {
        return progressRemark;
    }

    public void setProgressRemark(String progressRemark) {
        this.progressRemark = progressRemark;
    }

    public Date getProgressTime() {
        return progressTime;
    }

    public void setProgressTime(Date progressTime) {
        this.progressTime = progressTime;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getProjectSource() {
        return projectSource;
    }

    public void setProjectSource(String projectSource) {
        this.projectSource = projectSource;
    }

    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }

    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }

    public String getInnerName() {
        return innerName;
    }

    public void setInnerName(String innerName) {
        this.innerName = innerName;
    }

    public String getFinishFlag() {
        return finishFlag;
    }

    public void setFinishFlag(String finishFlag) {
        this.finishFlag = finishFlag;
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20240412.110652-287-sources.jar: com/ejianc/business/worklog/bean/WorkPlanEntity.java <==
package com.ejianc.business.worklog.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工作日志-工作计划
 *
 * @author generator
 */
@TableName("t_outputvalcount_work_plan")
public class WorkPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; // 单据编码
    @TableField(value = "org_id")
    private Long orgId; // 组织id
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "create_user_name")
    private String createUserName; // 编制人
    @TableField(value = "operator_id")
    private String operatorId; // 经办人ID
    @TableField(value = "operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value = "update_user_name")
    private String updateUserName; // 修改者
    @TableField(value = "remark")
    private String remark; // 备注
    @TableField(value = "work_type_id")
    private Long workTypeId; // 工作类别id
    @TableField(value = "work_type_code")
    private String workTypeCode; // 工作类别编号
    @TableField(value = "work_type_name")
    private String workTypeName; // 工作类别名称
    @TableField(value = "work_type_detail_id")
    private Long workTypeDetailId; // 工作详细类别id
    @TableField(value = "work_type_detail_code")
    private String workTypeDetailCode; // 工作详细类别编号
    @TableField(value = "work_type_detail_name")
    private String workTypeDetailName; // 工作详细类别名称
    @TableField(value = "project_code")
    private String projectCode; // 课题编号
    @TableField(value = "project_name")
    private String projectName; // 课题名称
    @TableField(value = "regist_time")
    private Date registTime; // 立项时间
    @TableField(value = "charge_org_id")
    private Long chargeOrgId; // 责任部门id
    @TableField(value = "charge_org_name")
    private String chargeOrgName; // 责任部门名称
    @TableField(value = "coordinate_org_id")
    private String coordinateOrgId; // 配合部门id
    @TableField(value = "coordinate_org_name")
    private String coordinateOrgName; // 配合部门名称
    @TableField(value = "regist_remark")
    private String registRemark; // 立项事由概述
    @TableField(value = "anticipated_results")
    private String anticipatedResults; // 预期成果
    @TableField(value = "end_time")
    private Date endTime; // 预计完成时间
    @TableField(value = "progress_id")
    private Long progressId; // 进展ID
    @TableField(value = "progress_name")
    private String progressName; // 进展
    @TableField(value = "progress_remark")
    private String progressRemark; // 进展描述
    @TableField(value = "progress_time")
    private Date progressTime; // 最新进展日期
    @TableField(value = "parent_id")
    private Long parentId; // 上级ID
    @TableField(value = "parent_name")
    private String parentName; // 上级名称
    @TableField(value = "project_source")
    private String projectSource; // 课题来源
    @TableField(value = "plan_type")
    private String planType; // 计划类型
    @TableField(value = "inner_code")
    private String innerCode; // 内码
    @TableField(value = "inner_name")
    private String innerName; // 内码名称
    @TableField(value = "finish_flag")
    private String finishFlag;//完成标识
    @TableField(value = "finish_date")
    private Date finishDate; // 完成日期

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getWorkTypeId() {
        return workTypeId;
    }

    public void setWorkTypeId(Long workTypeId) {
        this.workTypeId = workTypeId;
    }

    public String getWorkTypeCode() {
        return workTypeCode;
    }

    public void setWorkTypeCode(String workTypeCode) {
        this.workTypeCode = workTypeCode;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }

    public Long getWorkTypeDetailId() {
        return workTypeDetailId;
    }

    public void setWorkTypeDetailId(Long workTypeDetailId) {
        this.workTypeDetailId = workTypeDetailId;
    }

    public String getWorkTypeDetailCode() {
        return workTypeDetailCode;
    }

    public void setWorkTypeDetailCode(String workTypeDetailCode) {
        this.workTypeDetailCode = workTypeDetailCode;
    }

    public String getWorkTypeDetailName() {
        return workTypeDetailName;
    }

    public void setWorkTypeDetailName(String workTypeDetailName) {
        this.workTypeDetailName = workTypeDetailName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getRegistTime() {
        return registTime;
    }

    public void setRegistTime(Date registTime) {
        this.registTime = registTime;
    }

    public Long getChargeOrgId() {
        return chargeOrgId;
    }

    public void setChargeOrgId(Long chargeOrgId) {
        this.chargeOrgId = chargeOrgId;
    }

    public String getChargeOrgName() {
        return chargeOrgName;
    }

    public void setChargeOrgName(String chargeOrgName) {
        this.chargeOrgName = chargeOrgName;
    }

    public String getCoordinateOrgId() {
        return coordinateOrgId;
    }

    public void setCoordinateOrgId(String coordinateOrgId) {
        this.coordinateOrgId = coordinateOrgId;
    }

    public String getCoordinateOrgName() {
        return coordinateOrgName;
    }

    public void setCoordinateOrgName(String coordinateOrgName) {
        this.coordinateOrgName = coordinateOrgName;
    }

    public String getRegistRemark() {
        return registRemark;
    }

    public void setRegistRemark(String registRemark) {
        this.registRemark = registRemark;
    }

    public String getAnticipatedResults() {
        return anticipatedResults;
    }

    public void setAnticipatedResults(String anticipatedResults) {
        this.anticipatedResults = anticipatedResults;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Long getProgressId() {
        return progressId;
    }

    public void setProgressId(Long progressId) {
        this.progressId = progressId;
    }

    public String getProgressName() {
        return progressName;
    }

    public void setProgressName(String progressName) {
        this.progressName = progressName;
    }

    public String getProgressRemark() {
        return progressRemark;
    }

    public void setProgressRemark(String progressRemark) {
        this.progressRemark = progressRemark;
    }

    public Date getProgressTime() {
        return progressTime;
    }

    public void setProgressTime(Date progressTime) {
        this.progressTime = progressTime;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getProjectSource() {
        return projectSource;
    }

    public void setProjectSource(String projectSource) {
        this.projectSource = projectSource;
    }

    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }

    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }

    public String getInnerName() {
        return innerName;
    }

    public void setInnerName(String innerName) {
        this.innerName = innerName;
    }

    public String getFinishFlag() {
        return finishFlag;
    }

    public void setFinishFlag(String finishFlag) {
        this.finishFlag = finishFlag;
    }
    
    public Date getFinishDate() {
        return finishDate;
    }

    public void setFinishDate(Date finishDate) {
        this.finishDate = finishDate;
    }
}
